==> react-foundation-apps-0.2.0.tgz: package/docs/panel/index.jsx <==
var React = require('react');
var Highlight = require('react-highlight');
var FixedPanel = require('./fixed-panel');
var Panel = require('../../lib/panel');
var Open = require('../../lib/triggers/open');
var Close = require('../../lib/triggers/close');
var HardToggle = require('../../lib/triggers/hard-toggle');

var PanelDocs = React.createClass({
  render: function () {
    return (
      <div>
        <Panel id='example-top-panel' position='top'>
          <Close trigger='example-top-panel'>
            <a className='close-button'>&times;</a>
          </Close>
          Top Panel content
        </Panel> 
        <Panel id='example-right-panel' position='right'>
          <Close trigger='example-right-panel'>
            <a className='close-button'>&times;</a>
          </Close>
          Right Panel content
        </Panel> 
        <Panel id='example-bottom-panel' position='bottom'>
          <Close trigger='example-bottom-panel'>
            <a className='close-button'>&times;</a>
          </Close>
          Bottom Panel content
        </Panel> 
        <Panel id='example-left-panel'>
          <Close trigger='example-left-panel'>
            <a className='close-button'>&times;</a>
          </Close>
          Basic Left Panel content
        </Panel> 
        <h2>Panel</h2>
        <h4 className='subheader'>
          panel
        </h4> 
        <hr />
        <div className='grid-block'>
          <HardToggle trigger='example-top-panel'>
            <a className="button">Top Panel</a>
          </HardToggle>
          <HardToggle trigger='example-right-panel'>
            <a className="button">Right Panel</a>
          </HardToggle>
          <HardToggle trigger='example-bottom-panel'>
            <a className="button">Bottom Panel</a>
          </HardToggle>
          <HardToggle trigger='example-left-panel'>
            <a className="button">Left Panel</a>
          </HardToggle>
        </div>
        <hr />

        <h4>Basic Panel</h4>
        <p>Each panel should have unique id you can use to target it</p>
        <div className='grid-block'>
          <div className='grid-content'>
            <Highlight innerHTML={true}>
              {require('./basic.md')} 
            </Highlight>
          </div>
          <div className='grid-content'>
            <HardToggle trigger='example-left-panel'>
              <a className="button">Basic Panel</a>
            </HardToggle>
          </div>
        </div>
        <hr />

        <h4>Panel Trigger</h4>
        <p>You can trigger the panel by passing panel id to any trigger components like Open, Toggle, HardToggle, Close</p>
        <div className='grid-block'>
          <div className='grid-content'>
          </div>
          <div className='grid-content'>
            <HardToggle trigger='example-top-panel'>
              <a className="button">Top Panel</a>
            </HardToggle>
          </div>
        </div>
        <hr />

        <h4>Fixed Panel</h4>
        <div className='grid-block'>
          <div className='grid-content'>
            <Highlight innerHTML={true}>
              {require('./fixed-panel.md')}
            </Highlight>
          </div>
          <div className='grid-content'>
            <FixedPanel />
          </div>
        </div>
        <hr />

      </div>
    );
  }
});

module.exports = PanelDocs;

==> react-foundation-apps-0.3.0.tgz: package/docs/panel/index.jsx <==
var React = require('react');
var Highlight = require('react-highlight');
var FixedPanel = require('./fixed-panel');
var Panel = require('../../lib/panel');
var Trigger = require('../../lib/trigger');

var PanelDocs = React.createClass({
  render: function () {
    return (
      <div>
        <Panel id='example-top-panel' position='top'>
          <Trigger close='example-top-panel'>
            <a className='close-button'>&times;</a>
          </Trigger>
          Top Panel content
        </Panel> 
        <Panel id='example-right-panel' position='right'>
          <Trigger close='example-right-panel'>
            <a className='close-button'>&times;</a>
          </Trigger>
          Right Panel content
        </Panel> 
        <Panel id='example-bottom-panel' position='bottom'>
          <Trigger close='example-bottom-panel'>
            <a className='close-button'>&times;</a>
          </Trigger>
          Bottom Panel content
        </Panel> 
        <Panel id='example-left-panel'>
          <Trigger close='example-left-panel'>
            <a className='close-button'>&times;</a>
          </Trigger>
          Basic Left Panel content
        </Panel> 
        <h2>Panel</h2>
        <h4 className='subheader'>
          panel
        </h4> 
        <hr />
        <div className='grid-block'>
          <Trigger hardToggle='example-top-panel'>
            <a className="button">Top Panel</a>
          </Trigger>
          <Trigger hardToggle='example-right-panel'>
            <a className="button">Right Panel</a>
          </Trigger>
          <Trigger hardToggle='example-bottom-panel'>
            <a className="button">Bottom Panel</a>
          </Trigger>
          <Trigger hardToggle='example-left-panel'>
            <a className="button">Left Panel</a>
          </Trigger>
        </div>
        <hr />

        <h4>Basic Panel</h4>
        <p>Each panel should have unique id you can use to target it</p>
        <div className='grid-block'>
          <div className='grid-content'>
            <Highlight innerHTML={true}>
              {require('./basic.md')} 
            </Highlight>
          </div>
          <div className='grid-content'>
            <Trigger hardToggle='example-left-panel'>
              <a className="button">Basic Panel</a>
            </Trigger>
          </div>
        </div>
        <hr />

        <h4>Panel Trigger</h4>
        <p>Place the markup for panel component inside the block where panel should be revealed. You can trigger the panel with actions such as open, toggle, hardToggle using Trigger component</p>
        <div className='grid-block'>
          <div className='grid-content'>
            <Highlight innerHTML={true}>
              {require('./trigger.md')} 
            </Highlight>
          </div>
          <div className='grid-content'>
            <Trigger hardToggle='example-top-panel'>
              <a className="button">Top Panel</a>
            </Trigger>
          </div>
        </div>
        <hr />

        <h4>Fixed Panel</h4>
        <div className='grid-block'>
          <div className='grid-content'>
            <Highlight innerHTML={true}>
              {require('./fixed-panel.md')}
            </Highlight>
          </div>
          <div className='grid-content'>
            <FixedPanel />
          </div>
        </div>
        <hr />

      </div>
    );
  }
});

module.exports = PanelDocs;
